// T3h Package.
package kirk.gui.dialog;

// Import t3h AWT.
import java.awt.*;

/**
 * An entension of <code>PopupDialog</code> that asks the user for input. This class
 * is abstract, the actual input is asked by subclasses. These subclasses call
 * <code>setInputValue(Object value)</code> to set the value.
 * 
 * An <code>InputAcceptor</code> is required to retrieve the set values. These values
 * are actually a single <code>Object</code>, which can be anything. This way any
 * (amount of) values can be passed.
 * 
 * @author Berend "Kirk" Wouda
 * @version 1
 * @see kirk.gui.dialog.InputAcceptor
 */
public abstract class InputDialog extends PopupDialog {
	/**
	 * Constructs a new <code>InputDialog</code> with the passed message.
	 * 
	 * @param owner The pwning <code>Frame</code>.
	 * @param acceptor The <code>InputAcceptor</code> that gets its values set by
	 * this object.
	 * @param width The width of this <code>Dialog</code> in pixels.
	 * @param height The height of this <code>Dialog</code> in pixels.
	 */
	public InputDialog(Frame owner, InputAcceptor acceptor, int width, int height) {
		// Call the super constructor.
		super(owner, "Input Dialog", width, height);
		
		// Set the accceptor.
		this.acceptor = acceptor;
	}
	
	/**
	 * Sets the passed value in the acceptor.
	 * 
	 * Subclasses of this class call this method to set the value.
	 */
	protected void setInputValue(Object value) {
		// Set the value in the acceptor.
		acceptor.setInputValue(value);
	}
	
	
	/**
	 * The <code>InputAcceptor</code>.
	 */
	private InputAcceptor acceptor;
}