// T3h Package.
package kirk.gui.dialog;

// Import t3h AWT schtuff.
import java.awt.*;
import java.awt.event.*;

/**
 * An entension of <code>InputDialog</code> that asks the user for a single
 * <code>String</code>.
 * 
 * Use <code>InputRetriever</code> to easily get a value from this object.
 * 
 * @author Berend "Kirk" Wouda
 * @version 1
 * @see kirk.gui.dialog.InputAcceptor
 * @see kirk.gui.dialog.InputRetriever
 */
public class SingleInputDialog extends InputDialog {
	/**
	 * Constructs a new <code>SingleInputDialog<code> with the passed message.
	 * 
	 * @param owner The pwning <code>Frame</code>.
	 * @param acceptor The <code>InputAcceptor</code> the will get the value set.
	 * @param message The message to be displayed.
	 * @param width The width of this <code>Dialog</code> in pixels.
	 * @param width The height of this <code>Dialog</code> in pixels.
	 * @param columns The width of the input field in characters.
	 */
	public SingleInputDialog(Frame owner, InputAcceptor acceptor, String message, int width, int height, int columns) {
		// Call the super constructor.
		super(owner, acceptor, width, height);
		
		// Display the message.
		Label messagelabel = new Label(message);
		add(messagelabel);
		
		// Add a textfield to this Dialog.
		inputfield = new TextField(columns);
		add(inputfield);
		
		// Add an OK button to this Dialog. Make it close the window by generating an
		// ActionEvent.
		Button okbutton = new Button("OK");
		okbutton.addActionListener(this);
		add(okbutton);
	}
	
	
	/**
	 * Sets the value in the set <code>InputAcceptor</code>, and then closes this
	 * </code>Dialog</code>.
	 * 
	 * @param event The <code>ActionEvent</code>. Which we will not use.
	 * @see kirk.gui.dialog.PopupDialog#actionPerformed(java.awt.event.ActionEvent)
	 * @see kirk.gui.dialog.InputAcceptor#setInputValue(java.lang.Object)
	 */
	public void actionPerformed(ActionEvent event) {
		// Set the value in the textfield in the input acceptor.
		setInputValue(inputfield.getText());
		
		// Let PopupDialog close this thing down.
		super.actionPerformed(event);
	}

	
	/**
	 * The input field.
	 */
	TextField inputfield;
}